<h1 align="center">
    <img src="https://github.com/2003100127/deepdlncud/blob/main/docs/img/deepdlncud-logo.png?raw=true" width="200" height="55">
    <br>
</h1>

<hr>

![PyPI](https://img.shields.io/pypi/v/deepdlncud?logo=PyPI)
[![Downloads](https://pepy.tech/badge/deepdlncud)](https://pepy.tech/project/deepdlncud)
![](https://img.shields.io/github/stars/2003100127/deepdlncud?logo=GitHub&color=blue)

## 💻 Platform

![Python](https://img.shields.io/badge/-Python-000?&logo=Python)
![PyPI](https://img.shields.io/badge/-PyPI-000?&logo=PyPI)

## 🧭 Overview
DeepdlncUD is a deep learning-based tool for predicting small molecule-mediated upregulation or downregulation of lncRNA expression, offering high accuracy and scalability for large-scale lncRNA-targeted drug discovery.

> Whether you’re working in computational drug discovery, bioinformatics, or molecular pharmacology, DeepdlncUD provides a ready-to-use solution for drug screening.

## 📔 Documentation
Please check https://2003100127.github.io/deepdlncud for its usage.

## 🛠️ Installation

* ![PyPI](https://img.shields.io/badge/-PyPI-000?&logo=PyPI) (https://pypi.org/project/deepdlncud)

  ``` shell
  conda create --name deepdlncud python=3.11
      
  conda activate deepdlncud
  
  pip install deepdlncud --upgrade
  ```

## 📚 Citation

```shell!
Sun, J., Si, S., Ru, J., & Wang, X. (2023). DeepdlncUD: Predicting regulation types of small molecule inhibitors on modulating lncRNA expression by deep learning. Computers in biology and medicine, 163, 107226. https://doi.org/10.1016/j.compbiomed.2023.107226
```

```markdown
@article{deepdlncud2023,
    title = {DeepdlncUD: Predicting regulation types of small molecule inhibitors on modulating lncRNA expression by deep learning},
    author = {Jianfeng Sun and Shuyue Si and Jinlong Ru and Xia Wang},
    journal = {Computers in Biology and Medicine},
    volume = {163},
    pages = {107226},
    year = {2023},
    issn = {0010-4825},
    doi = {https://doi.org/10.1016/j.compbiomed.2023.107226},
    url = {https://www.sciencedirect.com/science/article/pii/S0010482523006911},
    keywords = {Long non-coding RNAs, Small molecules, Regulation types, Drug discovery, Deep learning},
    }
```

## 🏠 Developer
[Jianfeng Sun](https://www.2003100127.github.io) 

## 📧 Contact
[![Linkedin Badge](https://img.shields.io/badge/-Jianfeng_Sun-blue?style=flat-square&logo=Linkedin&logoColor=white&link=https://www.linkedin.com/in/jianfeng-sun-2ba9b1132)](https://www.linkedin.com/in/jianfeng-sun-2ba9b1132) 
[![Gmail Badge](https://img.shields.io/badge/-jianfeng.sunmt@gmail.com-c14438?style=flat-square&logo=Gmail&logoColor=white&link=mailto:jianfeng.sunmt@gmail.com)](mailto:jianfeng.sunmt@gmail.com)
[![Outlook Badge](https://img.shields.io/badge/jianfeng.sun@ndorms.ox.ac.uk--000?style=social&logo=microsoft-outlook&logoColor=0078d4&link=mailto:jianfeng.sun@ndorms.ox.ac.uk)](mailto:jianfeng.sun@ndorms.ox.ac.uk)
<a href="https://twitter.com/Jianfeng_Sunny" ><img src="https://img.shields.io/twitter/follow/Jianfeng_Sunny.svg?style=social" /></a>